==> ruta-2.8.1-source-release.zip: ruta-2.8.1/ruta-core/src/test/java/org/apache/uima/ruta/action/AssignActionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.ruta.action;

import org.apache.uima.cas.CAS;
import org.apache.uima.ruta.engine.Ruta;
import org.apache.uima.ruta.engine.RutaTestUtils;
import org.junit.Test;

public class AssignActionTest {

  @Test
  public void testBooleanListAssignment() throws Exception {
    String document = "This is a test.";

    String script = "";
    script += "BOOLEANLIST bl;";
    script += "ASSIGN(bl, {true});";
    script += "Document{CONTAINS(bl, true) -> T1};";

    CAS cas = RutaTestUtils.getCAS(document);
    Ruta.apply(cas, script);

    RutaTestUtils.assertAnnotationsEquals(cas, 1, 1, "This is a test.");
  }

  @Test
  public void testIntListAssignment() throws Exception {
    String document = "This is a test.";

    String script = "";
    script += "INTLIST il;";
    script += "ASSIGN(il, {1,2,3});";
    script += "Document{CONTAINS(il, 2) -> T1};";

    CAS cas = RutaTestUtils.getCAS(document);
    Ruta.apply(cas, script);

    RutaTestUtils.assertAnnotationsEquals(cas, 1, 1, "This is a test.");
  }

  @Test
  public void testStringListAssignment() throws Exception {
    String document = "This is a test.";

    String script = "";
    script += "STRINGLIST sl;";
    script += "ASSIGN(sl, {\"a\",\"b\"});";
    script += "Document{CONTAINS(sl, \"a\") -> T1};";

    CAS cas = RutaTestUtils.getCAS(document);
    Ruta.apply(cas, script);

    RutaTestUtils.assertAnnotationsEquals(cas, 1, 1, "This is a test.");
  }

  @Test
  public void testTypeListAssignment() throws Exception {
    String document = "This is a test.";

    String script = "";
    script += "TYPELIST tl;";
    script += "ASSIGN(tl, {CW, CAP});";
    script += "Document{CONTAINS(tl, CW) -> T1};";

    CAS cas = RutaTestUtils.getCAS(document);
    Ruta.apply(cas, script);

    RutaTestUtils.assertAnnotationsEquals(cas, 1, 1, "This is a test.");
  }
}

==> ruta-3.5.0-source-release.zip: ruta-3.5.0/ruta-core/src/test/java/org/apache/uima/ruta/action/AssignActionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.ruta.action;

import org.apache.uima.cas.CAS;
import org.apache.uima.ruta.engine.Ruta;
import org.apache.uima.ruta.engine.RutaTestUtils;
import org.junit.jupiter.api.Test;

public class AssignActionTest {

  @Test
  public void testBooleanListAssignment() throws Exception {
    String document = "This is a test.";

    String script = "";
    script += "BOOLEANLIST bl;";
    script += "ASSIGN(bl, {true});";
    script += "Document{CONTAINS(bl, true) -> T1};";

    CAS cas = RutaTestUtils.getCAS(document);
    Ruta.apply(cas, script);

    RutaTestUtils.assertAnnotationsEquals(cas, 1, 1, "This is a test.");
  }

  @Test
  public void testIntListAssignment() throws Exception {
    String document = "This is a test.";

    String script = "";
    script += "INTLIST il;";
    script += "ASSIGN(il, {1,2,3});";
    script += "Document{CONTAINS(il, 2) -> T1};";

    CAS cas = RutaTestUtils.getCAS(document);
    Ruta.apply(cas, script);

    RutaTestUtils.assertAnnotationsEquals(cas, 1, 1, "This is a test.");
  }

  @Test
  public void testStringListAssignment() throws Exception {
    String document = "This is a test.";

    String script = "";
    script += "STRINGLIST sl;";
    script += "ASSIGN(sl, {\"a\",\"b\"});";
    script += "Document{CONTAINS(sl, \"a\") -> T1};";

    CAS cas = RutaTestUtils.getCAS(document);
    Ruta.apply(cas, script);

    RutaTestUtils.assertAnnotationsEquals(cas, 1, 1, "This is a test.");
  }

  @Test
  public void testTypeListAssignment() throws Exception {
    String document = "This is a test.";

    String script = "";
    script += "TYPELIST tl;";
    script += "ASSIGN(tl, {CW, CAP});";
    script += "Document{CONTAINS(tl, CW) -> T1};";

    CAS cas = RutaTestUtils.getCAS(document);
    Ruta.apply(cas, script);

    RutaTestUtils.assertAnnotationsEquals(cas, 1, 1, "This is a test.");
  }
}
